pub enum StorageError {
InvalidAccountsPath,
StorageInUse,
NoStorage,
NoCurrentTransaction,
PathError(PathError),
RuntimeError(RuntimeError),
}Expand description
Account transaction errors
All errors that may occur when using the accoun transaction API. When the error variant encapsulates some other error type, this is where the error originates from the durable storage interface on the host runtime.
Variants
InvalidAccountsPath
Invalid accounts path. Could not get the string representation of the accounts storage path.
StorageInUse
Some path in durable storage was already in use when the storage interface needed to use it for holding a transaction.
NoStorage
Some storage operation was tried, but the storage doesn’t even have the base (original) layer of accounts available.
NoCurrentTransaction
Some transaction operation, commit or rollback, was attempted while no transaction was in progress.
PathError(PathError)
Tried to create an invalid path to accounts. Check that the path to the storage for original account values (the base layer) starts with a ‘/’ character (it should).
RuntimeError(RuntimeError)
Some error was encountered while using the durable storage. This may happen when doing some transaction operation.